@@ -48,7 +48,7 @@ class BaseContainer(SmartWidget):
    def getSmartWidget(self, *keys, named = True):
       result = None
       
-      if not len(keys):
+      if not keys:
          result = self._baseContainerNamedChildren if named else self._baseContainerChildren
       
       else:
@@ -99,7 +99,7 @@ class BaseContainer(SmartWidget):
       return result
    
    def _inflateChildren(self):
-      self._baseContainerChildren = CommonUIComponents._inflate(self, self._baseContainerChildren, self._smartWidgetConfig, self._namePrefix)
+      self._baseContainerChildren = CommonUIComponents._inflate(self, self._baseContainerChildren, self._smartWidgetStorage, self._namePrefix)
    
    @staticmethod
    def _defaultStyle(style = None):
