@@ -2,7 +2,7 @@ from tkinter.ttk import Entry as TtkEntry
 from .smartwidget import SmartWidget
 
 class Entry(SmartWidget, TtkEntry):
-   def __init__(self, master = None, **kw):
+   def __init__(self, master, **kw):
       SmartWidget._setFont(kw)
       
       SmartWidget._setVariable(kw, "StringVar", defaultValueKey = "text", variableKey = "textvariable")
